@@ -17,7 +17,7 @@ from data_product_sdk.cortex_databricks.data_platform.processing_utils import (
 from data_product_sdk.cortex_databricks.data_platform.profiling_utils import (
     calculate_profilling,
     get_link_table
-    
+
 )
 from data_product_sdk.cortex_databricks.data_platform.schema_utils import (
     get_schema_from_s3,
@@ -580,7 +580,7 @@ def landing_to_bronze(
 
     db_table = f"{db_name}.{dataset_name}"
 
-    
+
     if catalog_name != "hive_metastore":
         set_owner_to(spark, db_table, table_owner)
 
@@ -666,6 +666,11 @@ def bronze_to_silver(
     df = read_table(
         spark, db_name=input_db_name, table_name=input_table_name, where=where
     )
+
+    if df.rdd.isEmpty():
+        print("Dataframe is empty")
+        return True
+
     df = apply_processing_function(
         df=df,
         func=processing_function,
@@ -747,7 +752,7 @@ def bronze_to_silver(
                     .format('delta')\
                     .mode('append')\
                     .saveAsTable("cortex.data_governance_quality.tables")
-                print(f""" 
+                print(f"""
                 catalog_name : {catalog_name},
                 output_db_table : {output_db_table},
                 description : {tbl_properties.get('cortex.description')},
@@ -756,7 +761,7 @@ def bronze_to_silver(
 
             except Exception as e:
                 print(e)
-        else: 
+        else:
             print("ERROR : properties not found")
     return True
 
@@ -822,6 +827,11 @@ def silver_to_gold(
     df = read_table(
         spark, db_name=input_db_name, table_name=input_table_name, where=where
     )
+
+    if df.rdd.isEmpty():
+        print("Dataframe is empty")
+        return True
+
     df = apply_processing_function(
         df=df,
         func=processing_function,
@@ -908,10 +918,10 @@ def silver_to_gold(
 
             except Exception as e:
                 print(e)
-        else: 
+        else:
             print("ERROR : properties not found")
 
-        
+
 
 
 
@@ -975,6 +985,11 @@ def gold_to_diamond(
     df = read_table(
         spark, db_name=input_db_name, table_name=input_table_name, where=where
     )
+
+    if df.rdd.isEmpty():
+        print("Dataframe is empty")
+        return True
+
     df = apply_processing_function(
         df=df,
         func=processing_function,
@@ -1064,6 +1079,11 @@ def gold_to_kafka(
     df = read_table(
         spark, db_name=input_db_name, table_name=input_table_name, where=where
     )
+
+    if df.rdd.isEmpty():
+        print("Dataframe is empty")
+        return True
+        
     df = apply_processing_function(
         df=df,
         func=processing_function,
